[Pkg-owncloud-commits] [owncloud] 35/258: Scroll to new file/folder after adding

David Prévot taffit at moszumanska.debian.org
Sat Oct 11 17:22:18 UTC 2014


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository owncloud.

commit cfca88f20e0a246d08e7402efdde41695b44291a
Author: Vincent Petry <pvince81 at owncloud.com>
Date:   Thu Sep 4 12:33:38 2014 +0200

    Scroll to new file/folder after adding
    
    When creating a new file from the menu, the list now scrolls to that
    file.
---
 apps/files/js/file-upload.js |  4 ++--
 apps/files/js/filelist.js    | 11 ++++++++---
 2 files changed, 10 insertions(+), 5 deletions(-)

diff --git a/apps/files/js/file-upload.js b/apps/files/js/file-upload.js
index 310799b..460c243 100644
--- a/apps/files/js/file-upload.js
+++ b/apps/files/js/file-upload.js
@@ -629,7 +629,7 @@ OC.Upload = {
 								},
 								function(result) {
 									if (result.status === 'success') {
-										FileList.add(result.data, {hidden: hidden, animate: true});
+										FileList.add(result.data, {hidden: hidden, animate: true, scrollTo: true});
 									} else {
 										OC.dialogs.alert(result.data.message, t('core', 'Could not create file'));
 									}
@@ -645,7 +645,7 @@ OC.Upload = {
 								},
 								function(result) {
 									if (result.status === 'success') {
-										FileList.add(result.data, {hidden: hidden, animate: true});
+										FileList.add(result.data, {hidden: hidden, animate: true, scrollTo: true});
 									} else {
 										OC.dialogs.alert(result.data.message, t('core', 'Could not create folder'));
 									}
diff --git a/apps/files/js/filelist.js b/apps/files/js/filelist.js
index 402abbd..34d4885 100644
--- a/apps/files/js/filelist.js
+++ b/apps/files/js/filelist.js
@@ -716,9 +716,10 @@
 		 *
 		 * @param fileData map of file attributes
 		 * @param options map of attributes:
 		 * - "updateSummary": true to update the summary after adding (default), false otherwise
 		 * - "silent": true to prevent firing events like "fileActionsReady"
 		 * - "animate": true to animate preview loading (defaults to true here)
 		 * @return new tr element (not appended to the table)
 		 */
 		add: function(fileData, options) {
@@ -767,6 +768,10 @@
 				});
 			}
 
+			if (options.scrollTo) {
+				this.scrollTo(fileData.name);
+			}
+
 			// defaults to true if not defined
 			if (typeof(options.updateSummary) === 'undefined' || !!options.updateSummary) {
 				this.fileSummary.add(fileData, true);
@@ -716,9 +716,10 @@
 		 * @param fileData map of file attributes
 		 * @param options map of attributes:
-		 * - "updateSummary": true to update the summary after adding (default), false otherwise
-		 * - "silent": true to prevent firing events like "fileActionsReady"
-		 * - "animate": true to animate preview loading (defaults to true here)
+		 * @param options.updateSummary true to update the summary after adding (default), false otherwise
+		 * @param options.silent true to prevent firing events like "fileActionsReady"
+		 * @param options.animate true to animate preview loading (defaults to true here)
+		 * @param options.scrollTo true to automatically scroll to the file's location
 		 * @return new tr element (not appended to the table)
 		 */

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud.git



More information about the Pkg-owncloud-commits mailing list